Module: Authorization

Defined in:
lib/publishare/identity.rb,
lib/authorization.rb,
lib/publishare/parser.rb,
lib/publishare/exceptions.rb,
lib/publishare/hardwired_roles.rb,
lib/publishare/object_roles_table.rb

Overview

In order to use this mixin, you'll need to define roles by overriding the following functions:

User#has_role?(role) Return true or false depending on the roles (strings) passed in.

Model#accepts_role?(role, user) Return true or false depending on the roles (strings) this particular user has for this particular model object.

See http://www.writertopia.com/developers/authorization

Defined Under Namespace

Modules: Base, HardwiredRoles, Identity, ObjectRolesTable Classes: AuthorizationError, AuthorizationExpressionInvalid, CannotObtainModelClass, CannotObtainModelObject, CannotObtainUserObject, CannotSetObjectRoleWhenSimpleRoleTable, CannotSetRoleWhenHardwired, ModelDoesntImplementRoles, UserDoesntImplementID, UserDoesntImplementRoles